@@ -4,12 +4,14 @@
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
 
 import argcomplete
+
 from . import __version__
 
 COPYRIGHT = """
 Copyright (C) 2012-2020 Bluestar Solutions Sàrl (<http://bluestar.solutions>).
 Released under GNU AGPLv3."""
 
+
 class OBArgumentParser():
     args = None
 
@@ -27,14 +29,16 @@ goal help:
 
         parser_shared = ArgumentParser(add_help=False)
 
+        parser_odoo_shared = ArgumentParser(add_help=False)
+        parser_odoo_shared.add_argument(
+            "-t", "--test", dest="odoo_test", action="store_true",
+            help="Run with test configuration.")
+
         subparsers = parser.add_subparsers(metavar="<goal>")
 
         parser_odoo = subparsers.add_parser(
             'odoo', help="Run Odoo server normally.",
-            parents=[parser_shared, parser_shared])
-        parser_odoo.add_argument(
-            "-t", "--test", dest="odoo_test", action="store_true",
-            help="Run with test configuration.")
+            parents=[parser_shared, parser_odoo_shared])
         parser_odoo.add_argument(
             "-u", "--update", dest="odoo_update",
             nargs='?', metavar='all|<module1>[,<module2>…]',
@@ -62,7 +66,7 @@ goal help:
             'project.i18n.export',
             help="Export i18n templates files for addons specified "
             "in project configuration file.",
-            parents=[parser_shared])
+            parents=[parser_shared, parser_odoo_shared])
         parser_i18n_export.add_argument(
             '-d', "--database", dest="database",
             metavar='<database>',
