@@ -6,6 +6,10 @@ import subprocess
 from .console import out
 
 
+class CommandError(Exception):
+    pass
+
+
 class Command():
     def __init__(self, *args):
         self.args = args or []
@@ -15,13 +19,17 @@ class Command():
         try:
             process = subprocess.Popen(self.args, **kwargs)
             process.communicate()
+            if process.returncode:
+                out("Command exited with code {}!".format(
+                    process.returncode), 'error')
+                raise CommandError()
         except KeyboardInterrupt:
             try:
                 process.terminate()
                 process.wait()
             except OSError:
                 pass
-            out("Odoo stopped by keyboard interrupt!", 'warning')
+            out("Command stopped by keyboard interrupt!", 'warning')
 
     @staticmethod
     def run(cmd):
